@@ -9,6 +9,7 @@ from events import Events
 import threading
 import algorithm_unique_folder
 
+algorithm_path = "algorithm_unique_folder"
 
 class Algorunner:
     def __init__(self, options):
@@ -27,9 +28,12 @@ class Algorunner:
         try:
             cwd = os.getcwd()
             alg = options.algorithm
-            package = alg["path"]
+            package = algorithm_path
+            print('package {package}'.format(package=package))
             entry = alg["entryPoint"]
+            print('entry {entry}'.format(entry=entry))
             entryPoint = entry.replace("/", ".")
+            print('entryPoint {entryPoint}'.format(entry=entry))
             entryPoint = os.path.splitext(entryPoint)[0]
             os.chdir('{cwd}/{package}'.format(cwd=cwd, package=package))
             print('loading {entry}'.format(entry=entry))
